window.Gleam.initSearch([{"doc":"battlesnake","title":"battlesnake","content":"# Gleam Battlesnake\n\n[![Package Version](https://img.shields.io/hexpm/v/battlesnake)](https://hex.pm/packages/battlesnake)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/battlesnake/)\n\nA wrapper for the Battlesnake API, allowing you to start building the logic for\nyour Battlesnake without worrying about decoding the requests.\n\nTo get started, add the following packages to your project:\n```sh\ngleam add battlesnake mist wisp gleam_erlang\n```\n\nYou can use the `battlesnake.simple` function to set up a server like this:\n```gleam\nimport battlesnake\nimport battlesnake/gamestate.{type GameState}\nimport gleam/erlang/process\nimport mist\nimport wisp/wisp_mist\n\nfn on_move(gamestate: GameState) -&gt; battlesnake.Move {\n  // This function gets called every turn\n  // Ideally your snake would do something more interesting than just\n  // moving to the right!\n  battlesnake.move(battlesnake.Right)\n}\n\npub fn main() {\n  let assert Ok(color) = battlesnake.color_from_hex(&quot;#ffaff3&quot;)\n\n  let config =\n    battlesnake.config()\n    |&gt; battlesnake.with_color(color)\n\n  let handler = battlesnake.simple(config, on_move)\n\n  let assert Ok(_) =\n    handler\n    |&gt; wisp_mist.handler(&quot;&quot;)\n    |&gt; mist.new\n    |&gt; mist.port(8000)\n    |&gt; mist.start_http\n\n  process.sleep_forever()\n}\n```\n\nIf you need to preserve some state between turns, you can use the\n`battlesnake.stateful` function:\n```gleam\nimport battlesnake\nimport battlesnake/gamestate.{type GameState}\nimport gleam/erlang/process\nimport mist\nimport wisp/wisp_mist\n\ntype MyState {\n  MyState\n}\n\nfn on_start(gamestate: GameState) -&gt; MyState {\n  MyState\n}\n\nfn on_move(gamestate: GameState, state: MyState) -&gt; #(battlesnake.Move, MyState) {\n  #(battlesnake.move(battlesnake.Up), state)\n}\n\nfn on_end(gamestate: GameState, state: MyState) -&gt; Nil {\n  Nil\n}\n\npub fn main() {\n  let assert Ok(color) = battlesnake.color_from_hex(&quot;#ffaff3&quot;)\n\n  let config =\n    battlesnake.config()\n    |&gt; battlesnake.with_color(color)\n\n  let handler = battlesnake.stateful(config, on_start, on_move, on_end)\n\n  let assert Ok(_) =\n    handler\n    |&gt; wisp_mist.handler(&quot;&quot;)\n    |&gt; mist.new\n    |&gt; mist.port(8000)\n    |&gt; mist.start_http\n\n  process.sleep_forever()\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/battlesnake&gt;.\n","url":"index.html"},{"doc":"battlesnake/gamestate","title":"Battlesnake","content":"pub type Battlesnake {\n  Battlesnake(\n    id: String,\n    name: String,\n    health: Int,\n    body: List(Position),\n    latency: String,\n    head: Position,\n    length: Int,\n    shout: String,\n    squad: String,\n    customizations: Customizations,\n  )\n}\n A Battlesnake on the board.\nBattlesnake(\n  id: String,\n  name: String,\n  health: Int,\n  body: List(Position),\n  latency: String,\n  head: Position,\n  length: Int,\n  shout: String,\n  squad: String,\n  customizations: Customizations,\n)\n\nid\n&lt;p&gt;Unique identifier for this Battlesnake in the context of the current game.&lt;/p&gt;\n\nname\n&lt;p&gt;Name given to this Battlesnake by its author.&lt;/p&gt;\n\nhealth\n&lt;p&gt;Health value of this Battlesnake, between 0 and 100 inclusively.&lt;/p&gt;\n\nbody\n&lt;p&gt;List of coordinates representing this Battlesnake’s location on the game\nboard. This list is ordered from head to tail.&lt;/p&gt;\n\nlatency\n&lt;p&gt;The previous response time of this Battlesnake, in milliseconds. If the\nBattlesnake timed out and failed to respond, the game timeout will be\nreturned (&lt;code&gt;game.timeout&lt;/code&gt;).&lt;/p&gt;\n\nhead\n&lt;p&gt;Coordinates for this Battlesnake’s head. Equivalent to the first element of the body list.&lt;/p&gt;\n\nlength\n&lt;p&gt;Length of this Battlesnake from head to tail. Equivalent to the length of the body list.&lt;/p&gt;\n\nshout\n&lt;p&gt;Message shouted by this Battlesnake on the previous turn.&lt;/p&gt;\n\nsquad\n&lt;p&gt;The squad that the Battlesnake belongs to. Used to identify squad members in Squad Mode games.&lt;/p&gt;\n\ncustomizations\n&lt;p&gt;The collection of customizations that control how this Battlesnake is displayed.&lt;/p&gt;\n\nSynonyms:\nbattlesnake/gamestate.Battlesnake\nbattlesnake/gamestate Battlesnake","url":"battlesnake/gamestate.html#Battlesnake"},{"doc":"battlesnake/gamestate","title":"Board","content":"pub type Board {\n  Board(\n    height: Int,\n    width: Int,\n    food: List(Position),\n    hazards: List(Position),\n    snakes: List(Battlesnake),\n  )\n}\n\nBoard(\n  height: Int,\n  width: Int,\n  food: List(Position),\n  hazards: List(Position),\n  snakes: List(Battlesnake),\n)\n\nheight\n&lt;p&gt;The number of rows in the y-axis of the game board.&lt;/p&gt;\n\nwidth\n&lt;p&gt;The number of columns in the x-axis of the game board.&lt;/p&gt;\n\nfood\n&lt;p&gt;List of coordinates representing food locations on the game board.&lt;/p&gt;\n\nhazards\n&lt;p&gt;List of coordinates representing hazardous locations on the game board.&lt;/p&gt;\n\nsnakes\n&lt;p&gt;Array of Battlesnake Objects representing all Battlesnakes remaining on\nthe game board (including yourself if you haven’t been eliminated).&lt;/p&gt;\n\nSynonyms:\nbattlesnake/gamestate.Board\nbattlesnake/gamestate Board","url":"battlesnake/gamestate.html#Board"},{"doc":"battlesnake/gamestate","title":"Customizations","content":"pub type Customizations {\n  Customizations(color: String, head: String, tail: String)\n}\n The collection of customizations that control how this Battlesnake is displayed.\nCustomizations(color: String, head: String, tail: String)\n\n\nSynonyms:\nbattlesnake/gamestate.Customizations\nbattlesnake/gamestate Customizations","url":"battlesnake/gamestate.html#Customizations"},{"doc":"battlesnake/gamestate","title":"Game","content":"pub type Game {\n  Game(\n    id: String,\n    ruleset: Ruleset,\n    map: String,\n    timeout: Int,\n    source: String,\n  )\n}\n Holds general information about the current game.\nGame(\n  id: String,\n  ruleset: Ruleset,\n  map: String,\n  timeout: Int,\n  source: String,\n)\n\nid\n&lt;p&gt;A unique identifier for this game.&lt;/p&gt;\n\nruleset\n&lt;p&gt;Information about the ruleset being used to run this game.&lt;/p&gt;\n\nmap\n&lt;p&gt;The name of the map being played on.&lt;/p&gt;\n\ntimeout\n&lt;p&gt;How much time your snake has to respond to requests for this game in milliseconds.&lt;/p&gt;\n\nsource\n&lt;p&gt;The source of this game. One of:&lt;/p&gt;\n&lt;ul&gt;\n&lt;li&gt;“tournament”&lt;/li&gt;\n&lt;li&gt;“league” (for League Arenas)&lt;/li&gt;\n&lt;li&gt;“arena” (for all other Arenas)&lt;/li&gt;\n&lt;li&gt;“challenge”&lt;/li&gt;\n&lt;li&gt;“custom” (for all other games sources)&lt;/li&gt;\n&lt;/ul&gt;\n&lt;p&gt;The values for this field may change in the near future.&lt;/p&gt;\n\nSynonyms:\nbattlesnake/gamestate.Game\nbattlesnake/gamestate Game","url":"battlesnake/gamestate.html#Game"},{"doc":"battlesnake/gamestate","title":"GameState","content":"pub type GameState {\n  GameState(\n    game: Game,\n    turn: Int,\n    board: Board,\n    you: Battlesnake,\n  )\n}\n This gets sent by the server every time a game starts, ends, or a turn is requested.\nGameState(game: Game, turn: Int, board: Board, you: Battlesnake)\n\nturn\n&lt;p&gt;Turn number (starting at 0 for new games).&lt;/p&gt;\n\nSynonyms:\nbattlesnake/gamestate.GameState\nbattlesnake/gamestate GameState","url":"battlesnake/gamestate.html#GameState"},{"doc":"battlesnake/gamestate","title":"Position","content":"pub type Position {\n  Position(x: Int, y: Int)\n}\n A position on the game board. (0,0) is in the bottom left.\nPosition(x: Int, y: Int)\n\n\nSynonyms:\nbattlesnake/gamestate.Position\nbattlesnake/gamestate Position","url":"battlesnake/gamestate.html#Position"},{"doc":"battlesnake/gamestate","title":"RoyaleSettings","content":"pub type RoyaleSettings {\n  RoyaleSettings(shrink_every_n_turns: Int)\n}\n Ruleset settings for the Royale gamemode.\nRoyaleSettings(shrink_every_n_turns: Int)\n\nshrink_every_n_turns\n&lt;p&gt;In Royale mode, the number of turns between generating new hazards (shrinking the safe board space).&lt;/p&gt;\n\nSynonyms:\nbattlesnake/gamestate.RoyaleSettings\nbattlesnake/gamestate RoyaleSettings","url":"battlesnake/gamestate.html#RoyaleSettings"},{"doc":"battlesnake/gamestate","title":"Ruleset","content":"pub type Ruleset {\n  Ruleset(\n    name: String,\n    version: String,\n    settings: RulesetSettings,\n  )\n}\n\nRuleset(name: String, version: String, settings: RulesetSettings)\n\nname\n&lt;p&gt;Name of the ruleset being used to run this game.&lt;/p&gt;\n\nversion\n&lt;p&gt;The release version of the &lt;a href=&quot;https://github.com/BattlesnakeOfficial/rules&quot;&gt;Rules&lt;/a&gt; module used in this game.&lt;/p&gt;\n\nsettings\n&lt;p&gt;A collection of specific settings being used by the current game that control how the rules are applied.&lt;/p&gt;\n\nSynonyms:\nbattlesnake/gamestate.Ruleset\nbattlesnake/gamestate Ruleset","url":"battlesnake/gamestate.html#Ruleset"},{"doc":"battlesnake/gamestate","title":"RulesetSettings","content":"pub type RulesetSettings {\n  RulesetSettings(\n    food_spawn_chance: Int,\n    minimum_food: Int,\n    hazard_damage_per_turn: Int,\n    royale: RoyaleSettings,\n    squad: SquadSettings,\n  )\n}\n A collection of specific settings being used by the current game that control how the rules are applied.\nRulesetSettings(\n  food_spawn_chance: Int,\n  minimum_food: Int,\n  hazard_damage_per_turn: Int,\n  royale: RoyaleSettings,\n  squad: SquadSettings,\n)\n\nfood_spawn_chance\n&lt;p&gt;Percentage chance of spawning a new food every round.&lt;/p&gt;\n\nminimum_food\n&lt;p&gt;Minimum food to keep on the board every turn.&lt;/p&gt;\n\nhazard_damage_per_turn\n&lt;p&gt;Health damage a snake will take when ending its turn in a hazard. This stacks on top of the regular 1 damage a snake takes per turn.&lt;/p&gt;\n\nroyale\n&lt;p&gt;Ruleset settings for the Royale gamemode.&lt;/p&gt;\n\nsquad\n&lt;p&gt;Ruleset settings for the Squad gamemode.&lt;/p&gt;\n\nSynonyms:\nbattlesnake/gamestate.RulesetSettings\nbattlesnake/gamestate RulesetSettings","url":"battlesnake/gamestate.html#RulesetSettings"},{"doc":"battlesnake/gamestate","title":"SquadSettings","content":"pub type SquadSettings {\n  SquadSettings(\n    allow_body_collisions: Bool,\n    shared_elimination: Bool,\n    shared_health: Bool,\n    shared_length: Bool,\n  )\n}\n Ruleset settings for the Squad gamemode.\nSquadSettings(\n  allow_body_collisions: Bool,\n  shared_elimination: Bool,\n  shared_health: Bool,\n  shared_length: Bool,\n)\n\nallow_body_collisions\n&lt;p&gt;In Squad mode, allow members of the same squad to move over each other without dying.&lt;/p&gt;\n\nshared_elimination\n&lt;p&gt;In Squad mode, all squad members are eliminated when one is eliminated.&lt;/p&gt;\n\nshared_health\n&lt;p&gt;In Squad mode, all squad members share health.&lt;/p&gt;\n\nshared_length\n&lt;p&gt;In Squad mode, all squad members share length.&lt;/p&gt;\n\nSynonyms:\nbattlesnake/gamestate.SquadSettings\nbattlesnake/gamestate SquadSettings","url":"battlesnake/gamestate.html#SquadSettings"},{"doc":"battlesnake/gamestate","title":"battlesnake/gamestate","content":"","url":"battlesnake/gamestate.html"},{"doc":"battlesnake","title":"Color","content":"pub opaque type Color\n A representation of the color of a Battlesnake\n\nSynonyms:\nbattlesnake.Color\nbattlesnake Color","url":"battlesnake.html#Color"},{"doc":"battlesnake","title":"Direction","content":"pub type Direction {\n  Up\n  Down\n  Left\n  Right\n}\n The direction for your Battlesnake to move in.\nUp\n\n\nDown\n\n\nLeft\n\n\nRight\n\n\nSynonyms:\nbattlesnake.Direction\nbattlesnake Direction","url":"battlesnake.html#Direction"},{"doc":"battlesnake","title":"Move","content":"pub type Move {\n  Move(direction: Direction, shout: Option(String))\n}\n The response to move requests.\nMove(direction: Direction, shout: Option(String))\n\n\nSynonyms:\nbattlesnake.Move\nbattlesnake Move","url":"battlesnake.html#Move"},{"doc":"battlesnake","title":"SnakeConfig","content":"pub type SnakeConfig {\n  SnakeConfig(\n    apiversion: String,\n    author: Option(String),\n    color: Option(Color),\n    head: Option(String),\n    tail: Option(String),\n    version: Option(String),\n  )\n}\n Configures how your snake looks.\nSnakeConfig(\n  apiversion: String,\n  author: Option(String),\n  color: Option(Color),\n  head: Option(String),\n  tail: Option(String),\n  version: Option(String),\n)\n\napiversion\n&lt;p&gt;Version of the Battlesnake API implemented by this Battlesnake. Currently only API version 1 is valid. Example: “1”&lt;/p&gt;\n\nauthor\n&lt;p&gt;Username of the author of this Battlesnake. If provided, this will be used to verify ownership. Example: “BattlesnakeOfficial”&lt;/p&gt;\n\ncolor\n&lt;p&gt;Color of the Battlesnake.&lt;/p&gt;\n\nhead\n&lt;p&gt;Head customization. Example: “default”&lt;/p&gt;\n\ntail\n&lt;p&gt;Tail customization. Example: “default”&lt;/p&gt;\n\nversion\n&lt;p&gt;Optional version string for your Battlesnake. This value is not used in gameplay, but can be useful for tracking deployments on your end.&lt;/p&gt;\n\nSynonyms:\nbattlesnake.SnakeConfig\nbattlesnake SnakeConfig","url":"battlesnake.html#SnakeConfig"},{"doc":"battlesnake","title":"color_from_hex","content":"pub fn color_from_hex(color: String) -&gt; Result(Color, Nil)\n Convert a hex string to a Battlesnake color.\n \n Accepts the formats &#39;#000000&#39; or &#39;000000&#39;.\nSynonyms:\nbattlesnake.color_from_hex\nbattlesnake color_from_hex","url":"battlesnake.html#color_from_hex"},{"doc":"battlesnake","title":"color_from_rgb","content":"pub fn color_from_rgb(\n  r red: Int,\n  g green: Int,\n  b blue: Int,\n) -&gt; Result(Color, Nil)\n Create a Battlesnake color from red, green and blue components.\n \n Each value must be in the range 0..255.\nSynonyms:\nbattlesnake.color_from_rgb\nbattlesnake color_from_rgb","url":"battlesnake.html#color_from_rgb"},{"doc":"battlesnake","title":"config","content":"pub fn config() -&gt; SnakeConfig\n Create a base Battlesnake config.\nSynonyms:\nbattlesnake.config\nbattlesnake config","url":"battlesnake.html#config"},{"doc":"battlesnake","title":"move","content":"pub fn move(direction: Direction) -&gt; Move\n Create a move response with the given direction\nSynonyms:\nbattlesnake.move\nbattlesnake move","url":"battlesnake.html#move"},{"doc":"battlesnake","title":"shout","content":"pub fn shout(move: Move, shout: String) -&gt; Move\n Add an optional message to the move response that the other snakes can see\nSynonyms:\nbattlesnake.shout\nbattlesnake shout","url":"battlesnake.html#shout"},{"doc":"battlesnake","title":"simple","content":"pub fn simple(\n  config config: SnakeConfig,\n  on_move callback: fn(GameState) -&gt; Move,\n) -&gt; fn(Request(Connection)) -&gt; Response(Body)\n Use this function if your algorithm doesn&#39;t need to persist any state\n between moves. The returned handler ignores `/start` and `/end` requests and\n call your `on_move` function on every turn.\nSynonyms:\nbattlesnake.simple\nbattlesnake simple","url":"battlesnake.html#simple"},{"doc":"battlesnake","title":"stateful","content":"pub fn stateful(\n  config config: SnakeConfig,\n  on_start start: fn(GameState) -&gt; a,\n  on_move move: fn(GameState, a) -&gt; #(Move, a),\n  on_end end: fn(GameState, a) -&gt; Nil,\n) -&gt; fn(Request(Connection)) -&gt; Response(Body)\n This function lets you persist state between turns per game.\nSynonyms:\nbattlesnake.stateful\nbattlesnake stateful","url":"battlesnake.html#stateful"},{"doc":"battlesnake","title":"with_author","content":"pub fn with_author(\n  battlesnake: SnakeConfig,\n  author: String,\n) -&gt; SnakeConfig\n Add your Battlesnake username. If provided, this will be used to verify ownership.\nSynonyms:\nbattlesnake.with_author\nbattlesnake with_author","url":"battlesnake.html#with_author"},{"doc":"battlesnake","title":"with_color","content":"pub fn with_color(\n  battlesnake: SnakeConfig,\n  color: Color,\n) -&gt; SnakeConfig\n Add a color to your Battlesnake.\nSynonyms:\nbattlesnake.with_color\nbattlesnake with_color","url":"battlesnake.html#with_color"},{"doc":"battlesnake","title":"with_head","content":"pub fn with_head(\n  battlesnake: SnakeConfig,\n  head: String,\n) -&gt; SnakeConfig\n Add a head customization.\nSynonyms:\nbattlesnake.with_head\nbattlesnake with_head","url":"battlesnake.html#with_head"},{"doc":"battlesnake","title":"with_tail","content":"pub fn with_tail(\n  battlesnake: SnakeConfig,\n  tail: String,\n) -&gt; SnakeConfig\n Add a head customization.\nSynonyms:\nbattlesnake.with_tail\nbattlesnake with_tail","url":"battlesnake.html#with_tail"},{"doc":"battlesnake","title":"with_version","content":"pub fn with_version(\n  battlesnake: SnakeConfig,\n  version: String,\n) -&gt; SnakeConfig\n Add an optional version string to your Battlesnake. This value is not used in gameplay, but can be useful for tracking deployments on your end.\nSynonyms:\nbattlesnake.with_version\nbattlesnake with_version","url":"battlesnake.html#with_version"},{"doc":"battlesnake","title":"battlesnake","content":"","url":"battlesnake.html"}]);